MethodChannelBuzzBooster class

Inheritance

Constructors

MethodChannelBuzzBooster()

Properties

eventChannel → EventChannel
final
eventStream → Stream<MapEntry<NativeEvent, dynamic>>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
optInMarketinCampaignMoveButtonClickedEventStream → Stream<void>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleInitialMessage(Map<String, dynamic> data) → Future<void>
override
handleNotification(Map<String, dynamic> map) → Future<void>
override
handleOnMessageOpenedApp(Map<String, dynamic> data) → Future<void>
override
init({required String androidAppKey, required String iosAppKey}) → Future<void>
override
isBuzzBoosterNotification(Map<String, dynamic> map) → Future<bool>
override
isInitialized() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postJavaScriptMessage(String message) → Future<void>
override
sendEvent(String eventName, Map<String, Object>? eventValues) → Future<void>
override
setPushToken(String token) → Future<void>
override
setTheme(BuzzBoosterTheme theme) → Future<void>
override
setUser(User? user) → Future<void>
override
showCampaignWithId(String campaignId) → Future<void>
override
showCampaignWithType(CampaignType campaignType) → Future<void>
override
showHome() → Future<void>
override
showInAppMessage() → Future<void>
override
showNaverPayExchange() → Future<void>
override
showPage(String pageId) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited